@@ -9,9 +9,9 @@
 ABSESpy - Agent-based Social-ecological System framework in Python
 Copyright (c) 2021-2023 Shuang Song
 
-Documentation: https://agentpy.readthedocs.io/
-Examples: https://agentpy.readthedocs.io/en/latest/model_library.html
-Source: https://github.com/JoelForamitti/agentpy
+Documentation: https://songshgeo.github.io/ABSESpy
+Examples: https://songshgeo.github.io/ABSESpy/tutorial/user_guide/
+Source: https://github.com/SongshGeo/ABSESpy
 """
 
 __all__ = [
@@ -21,11 +21,14 @@ __all__ = [
     "BaseNature",
     "HumanModule",
     "PatchModule",
-    "Agent",
+    "Actor",
     "ActorsList",
-    "AgentsContainer" "MyExperiment",
+    "AgentsContainer",
+    "link_to",
+    "perception",
+    # "MyExperiment",
 ]
-__version__ = "v0.1.0"
+__version__ = "v0.1.3"
 
 from .actor import Actor, link_to, perception
 from .container import ActorsList, AgentsContainer
